"use strict";
/**
 * (C) Copyright IBM Corp. 2021.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
/**
 * IBM OpenAPI SDK Code Generator Version: 3.24.0-fac1d4cc-20210108-162022
 */
var extend = require("extend");
var ibm_cloud_sdk_core_1 = require("ibm-cloud-sdk-core");
var common_1 = require("../lib/common");
/**
 * SQL Query is a stateless service for analyzing rectangular data stored in IBM Cloud Object Store using ANSI SQL.
 */
var SqlV2 = /** @class */ (function (_super) {
    __extends(SqlV2, _super);
    /**
     * Construct a SqlV2 object.
     *
     * @param {Object} options - Options for the service.
     * @param {string} options.instanceCrn - The cloud resource name (CRN) of the SQL query service instance.
     * @param {string} [options.serviceUrl] - The base url to use when contacting the service. The base url may differ between IBM Cloud regions.
     * @param {OutgoingHttpHeaders} [options.headers] - Default headers that shall be included with every request to the service.
     * @param {Authenticator} options.authenticator - The Authenticator object used to authenticate requests to the service
     * @constructor
     * @returns {SqlV2}
     */
    function SqlV2(options) {
        var _this = this;
        options = options || {};
        var requiredParams = ['instanceCrn'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(options, requiredParams);
        if (missingParams) {
            throw missingParams;
        }
        _this = _super.call(this, options) || this;
        if (options.serviceUrl) {
            _this.setServiceUrl(options.serviceUrl);
        }
        else {
            _this.setServiceUrl(SqlV2.DEFAULT_SERVICE_URL);
        }
        _this.instanceCrn = options.instanceCrn;
        return _this;
    }
    /*************************
     * Factory method
     ************************/
    /**
     * Constructs an instance of SqlV2 with passed in options and external configuration.
     *
     * @param {UserOptions} [options] - The parameters to send to the service.
     * @param {string} [options.serviceName] - The name of the service to configure
     * @param {Authenticator} [options.authenticator] - The Authenticator object used to authenticate requests to the service
     * @param {string} [options.serviceUrl] - The URL for the service
     * @returns {SqlV2}
     */
    SqlV2.newInstance = function (options) {
        options = options || {};
        if (!options.serviceName) {
            options.serviceName = this.DEFAULT_SERVICE_NAME;
        }
        if (!options.authenticator) {
            options.authenticator = ibm_cloud_sdk_core_1.getAuthenticatorFromEnvironment(options.serviceName);
        }
        var service = new SqlV2(options);
        service.configureService(options.serviceName);
        if (options.serviceUrl) {
            service.setServiceUrl(options.serviceUrl);
        }
        return service;
    };
    /*************************
     * catalog
     ************************/
    /**
     * List catalog tables.
     *
     * Retrieve a list of the first 100 tables that are defined for the given instance in the catalog.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<SqlV2.Response<SqlV2.TableList>>}
     */
    SqlV2.prototype.listTables = function (params) {
        var _params = Object.assign({}, params);
        var query = {
            'instance_crn': this.instanceCrn
        };
        var sdkHeaders = common_1.getSdkHeaders(SqlV2.DEFAULT_SERVICE_NAME, 'v2', 'listTables');
        var parameters = {
            options: {
                url: '/tables',
                method: 'GET',
                qs: query,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Get information about a specific catalog table.
     *
     * Returns information about the specified catalog table.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.tableName - Name of the catalog table for which information is to be retrieved. Table names
     * are case-insensitive and must only contain alphabetic and numeral characters, and underscore (_).
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<SqlV2.Response<SqlV2.TableInformation>>}
     */
    SqlV2.prototype.getTable = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['tableName'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var query = {
            'instance_crn': this.instanceCrn
        };
        var path = {
            'table_name': _params.tableName
        };
        var sdkHeaders = common_1.getSdkHeaders(SqlV2.DEFAULT_SERVICE_NAME, 'v2', 'getTable');
        var parameters = {
            options: {
                url: '/tables/{table_name}',
                method: 'GET',
                qs: query,
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /*************************
     * sQLJobs
     ************************/
    /**
     * Run an SQL job.
     *
     * Runs an SQL job using the *IBM Cloud SQL Query* service and stores the result in a new CSV data set in *IBM Cloud
     * Object Storage*. The `FROM` clause references rectangular data that is stored in a Parquet, CSV, or JSON file in
     * *IBM Cloud Object Storage*. Click <a
     * href="https://console.bluemix.net/docs/services/sql-query/sql-query.html#overview">here</a> for more information.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.statement - This is the SQL query to be submitted. The table names specified in its FROM
     * clause must correspond to files in one or more *IBM Cloud Object Storage* instances. The INTO clause of the query
     * indicates the endpoint, bucket, and (optionally) subfolder in *IBM Cloud Object Storage* in which the query result
     * is to be stored. Within the specified target, each result is stored in a separate subfolder with a name that
     * indicates the job ID. The job ID of a query is returned by the GET endpoint.
     * @param {string} [params.resultsetTarget] - This field provides an alternative way to specify the target URI for a
     * query. It is supported to preserve backward compatibility and will be removed in a future API version. Use the INTO
     * clause of the SQL query to specify the target URI instead.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<SqlV2.Response<SqlV2.SqlJobInfoShort>>}
     */
    SqlV2.prototype.submitSqlJob = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['statement'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var body = {
            'statement': _params.statement,
            'resultset_target': _params.resultsetTarget
        };
        var query = {
            'instance_crn': this.instanceCrn
        };
        var sdkHeaders = common_1.getSdkHeaders(SqlV2.DEFAULT_SERVICE_NAME, 'v2', 'submitSqlJob');
        var parameters = {
            options: {
                url: '/sql_jobs',
                method: 'POST',
                body: body,
                qs: query,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                    'Content-Type': 'application/json',
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Get information about recent SQL jobs.
     *
     * Returns information about recently submitted SQL jobs.
     *
     * @param {Object} [params] - The parameters to send to the service.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<SqlV2.Response<SqlV2.SqlJobInfoList>>}
     */
    SqlV2.prototype.listSqlJobs = function (params) {
        var _params = Object.assign({}, params);
        var query = {
            'instance_crn': this.instanceCrn
        };
        var sdkHeaders = common_1.getSdkHeaders(SqlV2.DEFAULT_SERVICE_NAME, 'v2', 'listSqlJobs');
        var parameters = {
            options: {
                url: '/sql_jobs',
                method: 'GET',
                qs: query,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    /**
     * Get information about a specific SQL job.
     *
     * Returns information about the specified SQL job.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.jobId - ID of the SQL job for which information is to be retrieved. This ID is returned when
     * an SQL job is submitted, and when information about recently submitted SQL jobs is requested.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<SqlV2.Response<SqlV2.SqlJobInfoFull>>}
     */
    SqlV2.prototype.getSqlJob = function (params) {
        var _params = Object.assign({}, params);
        var requiredParams = ['jobId'];
        var missingParams = ibm_cloud_sdk_core_1.getMissingParams(_params, requiredParams);
        if (missingParams) {
            return Promise.reject(missingParams);
        }
        var query = {
            'instance_crn': this.instanceCrn
        };
        var path = {
            'job_id': _params.jobId
        };
        var sdkHeaders = common_1.getSdkHeaders(SqlV2.DEFAULT_SERVICE_NAME, 'v2', 'getSqlJob');
        var parameters = {
            options: {
                url: '/sql_jobs/{job_id}',
                method: 'GET',
                qs: query,
                path: path,
            },
            defaultOptions: extend(true, {}, this.baseOptions, {
                headers: extend(true, sdkHeaders, {
                    'Accept': 'application/json',
                }, _params.headers),
            }),
        };
        return this.createRequest(parameters);
    };
    ;
    SqlV2.DEFAULT_SERVICE_URL = 'https://api.sql-query.cloud.ibm.com/v2';
    SqlV2.DEFAULT_SERVICE_NAME = 'sql';
    return SqlV2;
}(ibm_cloud_sdk_core_1.BaseService));
module.exports = SqlV2;
//# sourceMappingURL=v2.js.map